@@ -16,7 +16,9 @@
 #include "khintssettings.h"
 #include "kiodelegate.h"
 #include "kwaylandintegration.h"
+#if QT_VERSION < QT_VERSION_CHECK(6, 9, 0)
 #include "qdbusmenubarwrapper.h"
+#endif
 #include "x11integration.h"
 
 #include <QApplication>
@@ -45,15 +47,12 @@
 
 using namespace Qt::StringLiterals;
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 9, 0)
 static const QByteArray s_x11AppMenuServiceNamePropertyName = QByteArrayLiteral("_KDE_NET_WM_APPMENU_SERVICE_NAME");
 static const QByteArray s_x11AppMenuObjectPathPropertyName = QByteArrayLiteral("_KDE_NET_WM_APPMENU_OBJECT_PATH");
 
 static bool checkDBusGlobalMenuAvailable()
 {
-    if (qEnvironmentVariableIsSet("KDE_NO_GLOBAL_MENU")) {
-        return false;
-    }
-
     QDBusConnection connection = QDBusConnection::sessionBus();
     QString registrarService = QStringLiteral("com.canonical.AppMenu.Registrar");
     return connection.interface()->isServiceRegistered(registrarService);
@@ -64,6 +63,7 @@ static bool isDBusGlobalMenuAvailable()
     static bool dbusGlobalMenuAvailable = checkDBusGlobalMenuAvailable();
     return dbusGlobalMenuAvailable;
 }
+#endif
 
 KdePlatformTheme::KdePlatformTheme()
 {
@@ -128,6 +128,11 @@ const QPalette *KdePlatformTheme::palette(Palette type) const
     }
 }
 
+Qt::ColorScheme KdePlatformTheme::colorScheme() const
+{
+    return m_hints->colorScheme();
+}
+
 const QFont *KdePlatformTheme::font(Font type) const
 {
     KFontSettingsData::FontTypes fdtype;
@@ -351,6 +356,10 @@ QPlatformSystemTrayIcon *KdePlatformTheme::createPlatformSystemTrayIcon() const
 
 QPlatformMenuBar *KdePlatformTheme::createPlatformMenuBar() const
 {
+    if (qEnvironmentVariableIsSet("KDE_NO_GLOBAL_MENU")) {
+        return nullptr;
+    }
+#if QT_VERSION < QT_VERSION_CHECK(6, 9, 0)
     if (isDBusGlobalMenuAvailable()) {
         auto dbusMenu = QGenericUnixTheme::createPlatformMenuBar();
         if (!dbusMenu) {
@@ -369,18 +378,17 @@ QPlatformMenuBar *KdePlatformTheme::createPlatformMenuBar() const
         return menu;
     }
     return nullptr;
+#else
+    return QGenericUnixTheme::createPlatformMenuBar();
+#endif
 }
 
 // Force QtQuickControls to use org.kde.desktop theme for QApplication,
 // and org.kde.breeze for QGuiApplication unless it's otherwise set.
 void KdePlatformTheme::setQtQuickControlsTheme()
 {
-    // if the user is running only a QGuiApplication, explicitly unset the QQC1 desktop style and use
-    // org.kde.breeze style if it's installed.
+    // if the user is running only a QGuiApplication, use org.kde.breeze style if it's installed.
     if (!qobject_cast<QApplication *>(qApp)) {
-        if (qgetenv("QT_QUICK_CONTROLS_1_STYLE").right(7) == "Desktop") {
-            qunsetenv("QT_QUICK_CONTROLS_1_STYLE");
-        }
         // /org/kde/breeze/components is not installed by org.kde.breeze, but the impl folder is
         if (checkIfThemeExists(QStringLiteral("/org/kde/breeze/impl"))) {
             QQuickStyle::setStyle(QStringLiteral("org.kde.breeze"));
@@ -403,6 +411,7 @@ bool KdePlatformTheme::useXdgDesktopPortal()
     return usePortal;
 }
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 9, 0)
 inline bool windowRelevantForGlobalMenu(QWindow *window)
 {
     return !(window->type() & Qt::WindowType::Popup);
@@ -422,6 +431,7 @@ void KdePlatformTheme::setMenuBarForWindow(QWindow *window, const QString &servi
         m_kwaylandIntegration->setAppMenu(window, serviceName, objectPath);
     }
 }
+#endif
 
 bool KdePlatformTheme::checkIfThemeExists(const QString &themePath)
 {
