@@ -29,6 +29,7 @@ public:
     QIcon fileIcon(const QFileInfo &fileInfo, QPlatformTheme::IconOptions iconOptions) const override;
 
     const QPalette *palette(Palette type = SystemPalette) const override;
+    Qt::ColorScheme colorScheme() const override;
     const QFont *font(Font type) const override;
     QIconEngine *createIconEngine(const QString &iconName) const override;
     QList<QKeySequence> keyBindings(QKeySequence::StandardKey key) const override;
@@ -43,7 +44,9 @@ public:
     QPlatformMenuBar *createPlatformMenuBar() const override;
 
 private:
+#if QT_VERSION < QT_VERSION_CHECK(6, 9, 0)
     void setMenuBarForWindow(QWindow *window, const QString &serviceName, const QString &objectPath) const;
+#endif
     void loadSettings();
     void setQtQuickControlsTheme();
 
